<?php declare(strict_types=1);

/**
 * Support: for detecting Environment
 */

namespace Infomaker\Everyware\Support;

use InvalidArgumentException;

/**
 * Class Environment
 * @package Infomaker\Everyware\Support
 */
class Environment
{
    public const ENV_VARIABLE = 'APP_ENV';
    public const PRODUCTION = 'prod';
    public const STAGED = 'stage';
    public const TEST = 'testing';
    public const DEVELOPMENT = 'local';

    protected static $validEnvironments = [self::PRODUCTION, self::STAGED, self::TEST, self::DEVELOPMENT];

    /**
     * Contains the current application environment
     *
     * @var string
     */
    protected static $currentEnv;

    /**
     * Retrieve current application environment
     *
     * @return string
     */
    public static function current(): string
    {
        if (static::$currentEnv === null) {
            static::setCurrent(env(self::ENV_VARIABLE, self::DEVELOPMENT));
        }

        return static::$currentEnv;
    }

    /**
     * Determine if environment is stage
     *
     * @return bool
     */
    public static function isStage(): bool
    {
        return static::current() === self::STAGED;
    }

    /**
     * Determine if environment is production
     *
     * @return bool
     */
    public static function isProd(): bool
    {
        return static::current() === self::PRODUCTION;
    }

    /**
     * Determine if environment is test
     *
     * @return bool
     * @since 0.6
     */
    public static function isTest(): bool
    {
        return static::current() === self::TEST;
    }

    /**
     * Determine if environment is development
     *
     * @return bool
     */
    public static function isDev(): bool
    {
        return static::current() === self::DEVELOPMENT;
    }

    /**
     * Set the current environment
     *
     * @param string $env
     *
     * @return void
     */
    public static function setCurrent($env): void
    {
        if ( ! \in_array($env, static::$validEnvironments, true)) {
            throw new InvalidArgumentException('Invalid environment given: ' . $env);
        }

        static::$currentEnv = $env;
    }
}
