<?php

use Infomaker\Everyware\Support\Device;
use Infomaker\Everyware\Support\Environment;

if ( ! function_exists('env')) {
    /**
     * Gets the value of an environment variable.
     *
     * @param  string $key
     * @param  mixed  $default
     *
     * @return mixed
     */
    function env(string $key, $default = null)
    {
        $value = getenv($key);

        if ($value === false) {
            return value($default);
        }

        switch (strtolower($value)) {
            case 'true':
            case '(true)':
                return true;
            case 'false':
            case '(false)':
                return false;
            case 'empty':
            case '(empty)':
                return '';
            case 'null':
            case '(null)':
                return null;
        }

        if (($valueLength = strlen($value)) > 1 && strpos($value, '"') === 0 && $value[$valueLength - 1] === '"') {
            return substr($value, 1, -1);
        }

        return $value;
    }
}

// Device Helpers:
// ======================================================
if ( ! function_exists('is_mobile')) {
    /**
     * Determine if device is mobile phone
     *
     * @return bool
     */
    function is_mobile(): bool
    {
        return Device::isMobile();
    }
}

if ( ! function_exists('is_tablet')) {
    /**
     * Determine if device tablet
     *
     * @return bool
     */
    function is_tablet(): bool
    {
        return Device::isTablet();
    }
}

if ( ! function_exists('is_desktop')) {
    /**
     * Determine if device is desktop
     *
     * @return bool
     */
    function is_desktop(): bool
    {
        return Device::isDesktop();
    }
}

// Environment Helpers: 
// ======================================================
if ( ! function_exists('is_prod')) {
    /**
     * Determine if we are in a production environment
     *
     * @return bool
     */
    function is_prod(): bool
    {
        return Environment::isProd();
    }
}

if ( ! function_exists('is_stage')) {
    /**
     * Determine if we are in a stage environment
     *
     * @return bool
     */
    function is_stage(): bool
    {
        return Environment::isStage();
    }
}

if ( ! function_exists('is_test')) {
    /**
     * Determine if we are in a test environment
     *
     * @return bool
     */
    function is_test(): bool
    {
        return Environment::isTest();
    }
}

if ( ! function_exists('is_dev')) {
    /**
     * Determine if we are in a development environment
     *
     * @return bool
     */
    function is_dev(): bool
    {
        return Environment::isDev();
    }
}
